-- Building Created Event
-- Author: Machiavelli
-- DateCreated: 6/25/2014 8:17:18 PM
--------------------------------------------------------------
-- Version 5
--
-- Depends on:
-- Unit Created event
--
-- Purpose:
-- Every building spawns a free unit which will have the unitType of "UNIT_BCE_BUILDINGCLASS_XXX"
-- (the BCE prefex is for "Building Created Event").  This function detects if a newly created unit
-- matches that format and if so indicates that they should be killed and fires the building
-- created event using the unitType to get the buildingClass.
--------------------------------------------------------------
function CallBuildingCreatedEvent(playerID, unitID, hexVec, unitType, cultureType, civID, primaryColor, secondaryColor, unitFlagIndex, fogState, selected, military, notInvisible)
	local player = Players[playerID];
	local unit = player:GetUnitByID(unitID);
	local plot = unit:GetPlot();
	local city;

	local unitType = GameInfo.Units[unit:GetUnitType()].Type;
	local subString = string.sub(unitType, 6, 22); -- UNIT_ | BCE_BUILDINGCLASS | _MONUMENT
	local buildingClass;
	
	-- Only do stuff if this is a unit that marks building created
	if(subString == "BCE_BUILDINGCLASS") then
		buildingClass = string.sub(unitType, 10); -- UNIT_BCE_ | BUILDINGCLASS_MONUMENT
		unit:SetHasPromotion(GameInfoTypes["PROMOTION_MARKED_FOR_DEATH"], true); -- Kill the unit after all other functions hooked into the unit created event have finished.
		
		if(plot:IsCity() and GameInfoTypes[buildingClass] ~= nil) then
			city = plot:GetPlotCity();
			--print("Calling BuildingCreatedEvent: PlayerID = " .. tostring(city:GetOwner()) .. " CityID = " .. tostring(city:GetID()) .. " BuildingClassID = " .. tostring(GameInfoTypes[buildingClass]));
			LuaEvents.BuildingCreatedEvent(city:GetOwner(), city:GetID(), GameInfoTypes[buildingClass]);
		end
	end
end
--LuaEvents.SerialEventUnitCreatedGood.Add(CallBuildingCreatedEvent);

--------------
-- Initialization check.  Ensures this code isn't loaded twice
--------------
local retVal = {};
LuaEvents.BuildingCreatedEvent_IsInitialized(retVal);

-- If retVal isn't changed, no other mod has initialized this code.
if (retVal.isInitialized == nil) then
	LuaEvents.BuildingCreatedEvent_IsInitialized.Add(function (retVal) retVal.isInitialized = true; end);
	-- Initialize the code
	LuaEvents.SerialEventUnitCreatedGood.Add(CallBuildingCreatedEvent);
end