-- Version 5
--
-- Purpose:
-- These sql statements create a new unitclass and unit for each buildingclass.
-- The third statement gives every building a free unit of its buildingclass.
----------------------------------
INSERT INTO UnitClasses(Type, Description, DefaultUnit)
	SELECT 'UNITCLASS_BCE_'||BuildingClass, 'TXT_KEY_UNIT_BUILDING_CREATED', 'UNIT_BCE_'||BuildingClass
	FROM Buildings
	WHERE Type IN (SELECT DefaultBuilding FROM BuildingClasses) AND ((Cost > 0) OR (FaithCost > 0 AND UnlockedByBelief = 1));

INSERT INTO Units(Class, Type, Domain, CombatLimit, Cost, Moves, Description)
	SELECT 'UNITCLASS_BCE_'||BuildingClass, 'UNIT_BCE_'||BuildingClass, 'DOMAIN_LAND', 0, -1, 2, 'TXT_KEY_UNIT_BUILDING_CREATED'
	FROM Buildings
	WHERE Type IN (SELECT DefaultBuilding FROM BuildingClasses) AND ((Cost > 0) OR (FaithCost > 0 AND UnlockedByBelief = 1));

INSERT INTO Building_FreeUnits(BuildingType, UnitType, NumUnits)
	SELECT Type, 'UNIT_BCE_'||BuildingClass, 1
	FROM Buildings
	WHERE ((Cost > 0) OR (FaithCost > 0 AND UnlockedByBelief = 1)) AND Type NOT IN (SELECT BuildingType FROM Building_FreeUnits WHERE UnitType = 'UNIT_BCE_'||BuildingClass);
	
-----------------------
-- DATABASE TRIGGERS --
-----------------------
CREATE TRIGGER IF NOT EXISTS BuildingCreatedEvent_NewBuildingClass
AFTER INSERT ON BuildingClasses
BEGIN
	INSERT INTO UnitClasses(Type, Description, DefaultUnit)
	VALUES('UNITCLASS_BCE_'||NEW.Type, 'TXT_KEY_UNIT_BUILDING_CREATED', 'UNIT_BCE_'||NEW.Type);
END;

CREATE TRIGGER IF NOT EXISTS BuildingCreatedEvent_DeletedBuildingClass
AFTER DELETE ON BuildingClasses
BEGIN
	DELETE FROM UnitClasses
	WHERE Type = 'UNITCLASS_BCE_'||OLD.Type;

	DELETE FROM Units
	WHERE Class = 'UNITCLASS_BCE_'||OLD.Type;
END;

CREATE TRIGGER IF NOT EXISTS BuildingCreatedEvent_NewBuilding
AFTER INSERT ON Buildings
WHEN ((NEW.Cost > 0) OR (NEW.FaithCost > 0 AND NEW.UnlockedByBelief = 1))
BEGIN
	INSERT OR IGNORE INTO Units(Class, Type, Domain, CombatLimit, Cost, Moves, Description)
	VALUES('UNITCLASS_BCE_'||NEW.BuildingClass, 'UNIT_BCE_'||NEW.BuildingClass, 'DOMAIN_LAND', 0, -1, 2, 'TXT_KEY_UNIT_BUILDING_CREATED');

	INSERT INTO Building_FreeUnits(BuildingType, UnitType, NumUnits)
	VALUES(NEW.Type, 'UNIT_BCE_'||NEW.BuildingClass, 1);
END;

CREATE TRIGGER IF NOT EXISTS BuildingCreatedEvent_DeletedBuilding
AFTER DELETE ON Buildings
WHEN ((OLD.Cost > 0) OR (OLD.FaithCost > 0 AND OLD.UnlockedByBelief = 1))
BEGIN
	DELETE FROM Building_FreeUnits
	WHERE BuildingType = OLD.Type;
END;

-- TODO: update triggers
--CREATE TRIGGER IF NOT EXISTS BuildingCreatedEvent_UpdatedBuilding
--AFTER UPDATE ON Buildings
--WHEN ((NEW.Cost > 0) OR (NEW.FaithCost > 0 AND NEW.UnlockedByBelief = 1) OR (OLD.Cost > 0) OR (OLD.FaithCost > 0 AND OLD.UnlockedByBelief = 1))
--BEGIN
--	DELETE FROM Building_FreeUnits
--	WHERE BuildingType = OLD.Type;
--END;